#include <ogr_api.h>
#include <cpl_conv.h>
#include <string>
#include <iostream>
#include <cassert>

void dump_layers(OGRDataSourceH ds)
{
    // Simple dump of layers
    for( int i = 0; i < OGR_DS_GetLayerCount(ds); ++i )
    {
        OGRLayerH hLyr = OGR_DS_GetLayer(ds, i);
        OGRFeatureDefnH hDef = OGR_L_GetLayerDefn(hLyr);

        std::cout << "Layer #" << i << ": " << OGR_FD_GetName(hDef) << std::endl;

        OGREnvelope e;
        OGRErr err = OGR_L_GetExtent(hLyr, &e, 1);
        if( OGRERR_NONE == err )
        {
            std::cout << "Extent: ("
                  << e.MinX << "," << e.MinY << "),(" 
                  << e.MaxX << "," << e.MaxY << ")\n";
        }
        
        // Dump first feature only
        OGR_L_ResetReading(hLyr);
        OGRFeatureH hFeat = OGR_L_GetNextFeature(hLyr);
        if( NULL != hFeat )
        {
            OGRGeometryH hGeom = OGR_F_GetGeometryRef(hFeat);
            if( NULL != hGeom )
            {
                char* wkt = NULL;
                err = OGR_G_ExportToWkt(hGeom, &wkt);
                assert(OGRERR_NONE == err);
                std::cout << wkt << std::endl;
                CPLFree(wkt);
            }
        }

        OGR_F_Destroy(hFeat);
    }

}

int main()
{
    OGRRegisterAll();

    std::string gml1("road1.gml");
    std::string gml2("road2.gml");

    std::cout << "Drivers number: " << OGRGetDriverCount() << std::endl;

    // Open two GML files
    OGRDataSourceH ds1 = OGROpen(gml1.c_str(), 0, NULL);
    assert(0 != ds1 && "Can not open gml1");
    
    OGRDataSourceH ds2 = OGROpen(gml2.c_str(), 0, NULL);
    assert(0 != ds2 && "Can not open gml2");

    // Close the first one
    OGRReleaseDataSource(ds1);

    // Try to read the second one that's still open
    dump_layers(ds2);
    
    OGRReleaseDataSource(ds2);

    return 0;
}
